==> SyL-0.11.5.tar.gz: SyL/opt/setupcmd/lib/CreateApplication.php <==
<?php
/**
 * ץꥱǥ쥯ȥݡͥȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateApplication.php,v 1.1 2007/05/27 16:24:29 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class CreateApplication
{
    /**
     * ץꥱǥ쥯ȥ
     *
     * @access public
     * @param string ץȥǥ쥯ȥ
     * @param string ץꥱ̾
     */
    function trigger($project_dir, $app_name)
    {
        $app_dir = "{$project_dir}app/{$app_name}/";
        if (!is_dir($app_dir)) {
            echo "  creating directory {$app_dir}\n"; ob_flush();
            if (!mkdir($app_dir, 0755)) {
                trigger_error("[SyL error] Application directory can't create ({$app_dir})", E_USER_ERROR);
                exit;
            }
        }

        $dirs = array(
          'actions'   => 0755,
          'templates' => 0755
        );

        foreach ($dirs as $dir => $mode) {
            if (!is_dir($app_dir . $dir)) {
                echo "  creating directory {$app_dir}{$dir}\n"; ob_flush();
                mkdir("{$app_dir}{$dir}");
                chmod("{$app_dir}{$dir}", $mode);
            }
        }

        echo "  copying file {$app_dir}actions.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/actions.xml")) {
            copy("{$project_dir}var/skel-templates/actions.xml", "{$app_dir}actions.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/actions.xml', "{$app_dir}actions.xml");
        }

        echo "  copying file {$app_dir}defines.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/defines_app.xml")) {
            copy("{$project_dir}var/skel-templates/defines_app.xml", "{$app_dir}defines.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/defines_app.xml', "{$app_dir}defines.xml");
        }

        echo "  copying file {$app_dir}filters.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/filters.xml")) {
            copy("{$project_dir}var/skel-templates/filters.xml", "{$app_dir}filters.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/filters.xml', "{$app_dir}filters.xml");
        }

        echo "  copying file {$app_dir}layouts.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/layouts.xml")) {
            copy("{$project_dir}var/skel-templates/layouts.xml", "{$app_dir}layouts.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/layouts.xml', "{$app_dir}layouts.xml");
        }
    }
}

?>

==> SyL-0.11.6.tar.gz: SyL/opt/setupcmd/lib/CreateApplication.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ץꥱǥ쥯ȥݡͥȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class CreateApplication
{
    /**
     * ץꥱǥ쥯ȥ
     *
     * @access public
     * @param string ץȥǥ쥯ȥ
     * @param string ץꥱ̾
     */
    function trigger($project_dir, $app_name)
    {
        $app_dir = "{$project_dir}app/{$app_name}/";
        if (!is_dir($app_dir)) {
            echo "  creating directory {$app_dir}\n"; ob_flush();
            if (!mkdir($app_dir, 0755)) {
                trigger_error("[SyL error] Application directory can't create ({$app_dir})", E_USER_ERROR);
                exit;
            }
        }

        $dirs = array(
          'actions'   => 0755,
          'templates' => 0755
        );

        foreach ($dirs as $dir => $mode) {
            if (!is_dir($app_dir . $dir)) {
                echo "  creating directory {$app_dir}{$dir}\n"; ob_flush();
                mkdir("{$app_dir}{$dir}");
                chmod("{$app_dir}{$dir}", $mode);
            }
        }

        echo "  copying file {$app_dir}actions.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/actions.xml")) {
            copy("{$project_dir}var/skel-templates/actions.xml", "{$app_dir}actions.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/actions.xml', "{$app_dir}actions.xml");
        }

        echo "  copying file {$app_dir}defines.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/defines_app.xml")) {
            copy("{$project_dir}var/skel-templates/defines_app.xml", "{$app_dir}defines.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/defines_app.xml', "{$app_dir}defines.xml");
        }

        echo "  copying file {$app_dir}filters.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/filters.xml")) {
            copy("{$project_dir}var/skel-templates/filters.xml", "{$app_dir}filters.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/filters.xml', "{$app_dir}filters.xml");
        }

        echo "  copying file {$app_dir}layouts.xml\n"; ob_flush();
        if (file_exists("{$project_dir}var/skel-templates/layouts.xml")) {
            copy("{$project_dir}var/skel-templates/layouts.xml", "{$app_dir}layouts.xml");
        } else {
            copy(SYL_PROJECT_DIR . '/var/skel-templates/layouts.xml', "{$app_dir}layouts.xml");
        }
    }
}

?>
